===============================
castellan
===============================

Generic Key Manager interface for OpenStack

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/castellan
* Source: http://git.openstack.org/cgit/openstack/castellan
* Bugs: http://bugs.launchpad.net/castellan

Features
--------

* TODO
